@@ -1,12 +1,12 @@
-// SPDX-FileCopyrightText: 2003-2022 Jesper K. Pedersen <jesper.pedersen@kdab.com>
-// SPDX-FileCopyrightText: 2005, 2007 Dirk Mueller <mueller@kde.org>
+// SPDX-FileCopyrightText: 2003 - 2022 Jesper K. Pedersen <jesper.pedersen@kdab.com>
+// SPDX-FileCopyrightText: 2005 2007 Dirk Mueller <mueller@kde.org>
 // SPDX-FileCopyrightText: 2006 Tuomas Suutari <tuomas@nepnep.net>
+// SPDX-FileCopyrightText: 2008 - 2009 Jan Kundrát <jkt@flaska.net>
 // SPDX-FileCopyrightText: 2008 Henner Zeller <h.zeller@acm.org>
-// SPDX-FileCopyrightText: 2008-2009 Jan Kundrát <jkt@flaska.net>
 // SPDX-FileCopyrightText: 2011 Andreas Neustifter <andreas.neustifter@gmail.com>
 // SPDX-FileCopyrightText: 2012 Miika Turkia <miika.turkia@gmail.com>
-// SPDX-FileCopyrightText: 2013-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
-// SPDX-FileCopyrightText: 2015-2018 Tobias Leupold <tl@stonemx.de>
+// SPDX-FileCopyrightText: 2013 - 2024 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2015 - 2018 Tobias Leupold <tl@stonemx.de>
 // SPDX-FileCopyrightText: 2016 Matthias Füssel <matthias.fuessel@gmx.net>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
@@ -23,8 +23,8 @@
 #include <DB/CategoryCollection.h>
 #include <DB/ImageDB.h>
 #include <DB/search/ImageSearchInfo.h>
-#include <Utilities/FileUtil.h>
 #include <Utilities/ShowBusyCursor.h>
+#include <kpabase/FileUtil.h>
 #include <kpabase/SettingsData.h>
 
 #include <KLocalizedString>
@@ -145,9 +145,11 @@ void Browser::BrowserWidget::emitSignals()
 
     if (isCategoryAction) {
         DB::CategoryPtr category = DB::ImageDB::instance()->categoryCollection()->categoryForName(currentCategory());
-        Q_ASSERT(category.data());
-
-        Q_EMIT currentViewTypeChanged(category->viewType());
+        // category may be deleted by now:
+        if (!category) {
+            home();
+            return;
+        }
     }
 
     Q_EMIT pathChanged(createPath());
