@@ -1,5 +1,5 @@
-// SPDX-FileCopyrightText: 2003-2020 The KPhotoAlbum Development Team
-// SPDX-FileCopyrightText: 2021-2023 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
+// SPDX-FileCopyrightText: 2003 - 2020 The KPhotoAlbum Development Team
+// SPDX-FileCopyrightText: 2021 - 2024 Johannes Zarl-Zierl <johannes@zarl-zierl.at>
 //
 // SPDX-License-Identifier: GPL-2.0-or-later
 
@@ -61,6 +61,7 @@
 #include <kpaexif/Database.h>
 #include <kpaexif/Info.h>
 #include <kpathumbnails/ThumbnailCache.h>
+#include <kpathumbnails/VideoThumbnailCache.h>
 
 #ifdef KF5Purpose_FOUND
 #include <Plugins/PurposeMenu.h>
@@ -253,6 +254,7 @@ MainWindow::Window::~Window()
 {
     DB::ImageDB::deleteInstance();
     delete m_thumbnailCache;
+    delete m_videoThumbnailCache;
 }
 
 void MainWindow::Window::delayedInit()
@@ -1201,26 +1203,41 @@ bool MainWindow::Window::load()
     if (configFile.startsWith(QString::fromLatin1("~")))
         configFile = QDir::home().path() + QString::fromLatin1("/") + configFile.mid(1);
 
-    // To avoid a race conditions where both the image loader thread creates an instance of
-    // Settings, and where the main thread crates an instance, we better get it created now.
-    Settings::SettingsData::setup(QFileInfo(configFile).absolutePath(), *this);
-
-    if (Settings::SettingsData::instance()->showSplashScreen()) {
-        SplashScreen::instance()->show();
-        qApp->processEvents();
-    }
-
     // Doing some validation on user provided index file
+    // dbFile is a valid QUrl?
     if (Options::the()->dbFile().isValid()) {
         QFileInfo fi(configFile);
 
-        if (!fi.dir().exists()) {
-            KMessageBox::error(this, i18n("<p>Could not open given index.xml, as the provided folder does not exist.<br />%1</p>", fi.absolutePath()));
-            return false;
+        // Did the user pass a directory on the command line?
+        if (fi.isDir()) {
+            fi.setFile(QDir(configFile).filePath(QLatin1String("index.xml")));
+        } else {
+            // fi is not a directory
+            QString errorMessage;
+            if (fi.fileName() != QString::fromLatin1("index.xml")) {
+                if (fi.isFile() && fi.exists()) {
+                    // existing file, wrong name
+                    // Note: we don't allow this currently because 'index.xml' is hard-coded at several places
+                    qCWarning(MainWindowLog) << "Config file is incorrectly named:" << fi.filePath();
+                    errorMessage = i18n("KPhotoAlbum only supports database files named 'index.xml'.");
+                } else {
+                    // non-existing file, wrong name
+                    qCWarning(MainWindowLog) << "No KPhotoAlbum index.xml database file was found:"
+                                             << configFile;
+                    errorMessage = i18n("Please specify an existing image directory or an existing index.xml file.");
+                }
+            } else if (!fi.dir().exists()) {
+                // index.xml within a non-existing directory
+                qCWarning(MainWindowLog) << "Directory of index.xml database file does not exist:"
+                                         << configFile;
+                errorMessage = i18n("Please specify an existing image directory or an existing index.xml file.");
+            }
+            if (!errorMessage.isEmpty()) {
+                KMessageBox::error(this, errorMessage, i18n("Invalid database file"));
+                return false;
+            }
         }
 
-        // We use index.xml as the XML backend, thus we want to test for exactly it
-        fi.setFile(QString::fromLatin1("%1/index.xml").arg(fi.dir().absolutePath()));
         if (!fi.exists()) {
             const QString question = i18n("<p>Given index file does not exist, do you want to create following?"
                                           "<br />%1/index.xml</p>",
@@ -1241,6 +1258,16 @@ bool MainWindow::Window::load()
         }
         configFile = fi.absoluteFilePath();
     }
+
+    // To avoid a race conditions where both the image loader thread creates an instance of
+    // Settings, and where the main thread creates an instance, we better get it created now.
+    Settings::SettingsData::setup(QFileInfo(configFile).absolutePath(), *this);
+
+    if (Settings::SettingsData::instance()->showSplashScreen()) {
+        SplashScreen::instance()->show();
+        qApp->processEvents();
+    }
+
     DB::ImageDB::setupXMLDB(configFile, *this);
 
     const QString thumbnailDirectory = QDir(Settings::SettingsData::instance()->imageDirectory()).absoluteFilePath(ImageManager::defaultThumbnailDirectory());
@@ -1248,6 +1275,9 @@ bool MainWindow::Window::load()
     // thumbnail size from cache overrides config value:
     Settings::SettingsData::instance()->setThumbnailSize(m_thumbnailCache->thumbnailSize());
 
+    const auto videoThumbnailDirectory = QDir(Settings::SettingsData::instance()->imageDirectory()).absoluteFilePath(ImageManager::defaultVideoThumbnailDirectory());
+    m_videoThumbnailCache = new ImageManager::VideoThumbnailCache { videoThumbnailDirectory };
+
     // some sanity checks:
     if (!DB::ImageDB::instance()->untaggedCategoryFeatureConfigured()
         && !(Settings::SettingsData::instance()->untaggedCategory().isEmpty()
@@ -1519,6 +1549,11 @@ ImageManager::ThumbnailCache *MainWindow::Window::thumbnailCache() const
     return m_thumbnailCache;
 }
 
+ImageManager::VideoThumbnailCache *MainWindow::Window::videoThumbnailCache() const
+{
+    return m_videoThumbnailCache;
+}
+
 void MainWindow::Window::slotImport()
 {
     ImportExport::Import::imageImport();
